@@ -191,6 +191,18 @@ class NamespaceDict(dict):
         return NamespaceDict(copy.deepcopy(self.copy(), memodict))
 
 
+class SafeNamespaceDict(NamespaceDict):
+    """
+    A Dict that does not expose values when represented as a string
+    """
+
+    def __repr__(self):
+        return str({k: "*" for k in self})
+
+    def __str__(self):
+        return repr(self)
+
+
 class FileDict(Mapping):
     """
     A dictionary type that stores it's information in a file
